@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Test::Trap ();        # load as early as possible to override CORE::exit
 
-our $VERSION = '0.36';
+our $VERSION = '0.39';
 
 use base qw(Exporter);
 
@@ -17,8 +17,8 @@ use constant { DEFINITION_PHASE => 0, EXECUTION_PHASE => 1 };
 our $TODO;
 our $Debug = $ENV{TEST_SPEC_DEBUG} || 0;
 
-our @EXPORT      = qw(runtests describe before after it they *TODO
-                      shared_examples_for it_should_behave_like
+our @EXPORT      = qw(runtests describe xdescribe before after it xit they
+                      xthey *TODO share shared_examples_for it_should_behave_like
                       spec_helper);
 our @EXPORT_OK   = ( @EXPORT, qw(DEFINITION_PHASE EXECUTION_PHASE $Debug) );
 our %EXPORT_TAGS = ( all => \@EXPORT_OK,
@@ -166,7 +166,11 @@ sub it(@) {
     Carp::croak "it() requires at least one of (description,code)";
   }
   $name ||= "behaves as expected (whatever that means)";
-  push @{ _autovivify_context($package)->tests }, { name => $name, code => $code };
+  push @{ _autovivify_context($package)->tests }, {
+    name => $name,
+    code => $code,
+    todo => $TODO,
+  };
   return;
 }
 
@@ -184,16 +188,16 @@ sub describe(@) {
   }
   my $name = shift || $package;
 
-  my $parent;
+  my $container;
   if ($_Current_Context) {
-    $parent = $_Current_Context->context_lookup;
+    $container = $_Current_Context->context_lookup;
   }
   else {
-    $parent = $_Package_Contexts->{$package} ||= _ixhash();
+    $container = $_Package_Contexts->{$package} ||= _ixhash();
   }
 
   __PACKAGE__->_accumulate_examples({
-    parent => $parent,
+    container => $container,
     name => $name,
     class => $package,
     code => $code,
@@ -201,6 +205,22 @@ sub describe(@) {
   });
 }
 
+# used to easily disable suites/specs during development
+sub xit(@) {
+  local $TODO = '(disabled)';
+  it(@_);
+}
+
+sub xthey(@) {
+  local $TODO = '(disabled)';
+  they(@_);
+}
+
+sub xdescribe(@) {
+  local $TODO = '(disabled)';
+  describe(@_);
+}
+
 # shared_examples_for DESC => CODE
 sub shared_examples_for($&) {
   my $package = caller;
@@ -217,9 +237,9 @@ sub shared_examples_for($&) {
   }
 
   __PACKAGE__->_accumulate_examples({
-    parent => $_Shared_Example_Groups,
+    container => $_Shared_Example_Groups,
     name => $name,
-    class => $package,
+    class => undef,   # shared examples are global
     code => $code,
     label => '',
   });
@@ -229,7 +249,7 @@ sub shared_examples_for($&) {
 # groups in context
 sub _accumulate_examples {
   my ($klass,$args) = @_;
-  my $parent = $args->{parent};
+  my $container = $args->{container};
   my $name = $args->{name};
   my $class = $args->{class};
   my $code = $args->{code};
@@ -237,15 +257,21 @@ sub _accumulate_examples {
 
   my $context;
   # Don't clobber contexts of the same name, aggregate them.
-  if ($parent->{$name}) {
-    $context = $parent->{$name};
+  if ($container->{$name}) {
+    $context = $container->{$name};
   }
   else {
-    $context = Test::Spec::Context->new;
+    $container->{$name} = $context = Test::Spec::Context->new;
     $context->name( $label );
-    $context->class( $class );
-    $context->parent( $_Current_Context ); # might be undef
-    $parent->{$name} = $context;
+    # A context gets either a parent or a class. This is because the
+    # class should be inherited from the parent to support classless
+    # shared example groups.
+    if ($_Current_Context) {
+      $context->parent( $_Current_Context );
+    }
+    else {
+      $context->class( $class );
+    }
   }
 
   # push a context onto the stack
@@ -253,7 +279,7 @@ sub _accumulate_examples {
 
   # evaluate the context function, which will set up lexical variables and
   # define tests and other contexts
-  $context->contextualize(sub { $code->() }); 
+  $context->contextualize($code); 
 }
 
 # it_should_behave_like DESC
@@ -268,9 +294,15 @@ sub it_should_behave_like($) {
   my $context = $_Shared_Example_Groups->{$name} ||
     Carp::croak "unrecognized example group \"$name\"";
 
+  # make a copy so we can assign the correct class name (via parent),
+  # which is needed for flattening the context into actual test
+  # functions later.
+  my $shim = $context->clone;
+  $shim->parent($_Current_Context);
+
   # add our shared_examples_for context as if it had been written inline
   # as a describe() block
-  $_Current_Context->context_lookup->{"__shared_examples__:$name"} = $context;
+  $_Current_Context->context_lookup->{"__shared_examples__:$name"} = $shim;
 }
 
 # before CODE
@@ -333,6 +365,11 @@ sub spec_helper ($) {
   $sub->($load_path,$filespec);
 }
 
+sub share(\%) {
+  my $hashref = shift;
+  tie %$hashref, 'Test::Spec::SharedHash';
+}
+
 sub _materialize_tests {
   my $class = shift;
   my $contexts = $_Package_Contexts->{$class};
@@ -392,6 +429,7 @@ sub _ixhash {
 
 # load context implementation
 require Test::Spec::Context;
+require Test::Spec::SharedHash;
 
 1;
 
@@ -466,9 +504,11 @@ When given B<no list> (i.e. C<use Test::Spec;>), this class will export:
 
 =over 4
 
-=item * C<describe>, C<it>, C<before>, C<after>, and C<runtests>
+=item * Spec definition functions
 
-These are the functions you will use to define behaviors and run your specs.
+These are the functions you will use to define behaviors and run your specs:
+C<describe>, C<it>, C<they>, C<before>, C<after>, C<runtests>, C<share>,
+C<shared_examples_for>, C<it_should_behave_like>, and C<spec_helper>.
 
 =item * The stub/mock functions in L<Test::Spec::Mocks>.
 
@@ -579,6 +619,12 @@ C<describe> blocks with the same name are allowed. They do not replace each
 other, rather subsequent C<describe>s extend the existing one of the same
 name.
 
+=item xdescribe
+
+Specification contexts may be disabled by calling C<xdescribe> instead of
+describe(). All examples inside an C<xdescribe> are reported as
+"# TODO (disabled)", which prevents Test::Harness/prove from counting them
+as failures.
 
 =item it SPECIFICATION => CODE
 
@@ -605,7 +651,7 @@ not failed.
 
 =item they CODE
 
-=item TODO_SPECIFICATION
+=item they TODO_SPECIFICATION
 
 An alias for L</it>.  This is useful for describing behavior for groups of
 items, so the verb agrees with the noun:
@@ -617,6 +663,12 @@ items, so the verb agrees with the noun:
     they "put the lotion in the basket"; # TODO
   };
 
+=item xit/xthey
+
+Examples may be disabled by calling xit()/xthey() instead of it()/they().
+These examples are reported as "# TODO (disabled)", which prevents
+Test::Harness/prove from counting them as failures.
+
 =item before each => CODE
 
 =item before all => CODE
@@ -668,15 +720,18 @@ L</Shared example groups>.
 
 Example group names are B<global>.
 
+  my $browser;
   shared_examples_for "all browsers" => sub {
-    it "should open a URL";
+    it "should open a URL" => sub { ok($browser->open("http://www.google.com/")) };
     ...
   };
   describe "Firefox" => sub {
+    before all => sub { $browser = Firefox->new };
     it_should_behave_like "all browsers";
     it "should have firefox features";
   };
   describe "Safari" => sub {
+    before all => sub { $browser = Safari->new };
     it_should_behave_like "all browsers";
     it "should have safari features";
   };
@@ -690,6 +745,33 @@ copying all the tests from the named C<shared_examples_for> block into
 the current context. See L</Shared example groups> and
 L<shared_examples_for>.
 
+=item share %HASH
+
+Registers C<%HASH> for sharing data between tests and example groups.
+This lets you share variables with code in different lexical scopes
+without resorting to using package (i.e. global) variables or jumping
+through other hoops to circumvent scope problems.
+
+Every hash that is C<share>d refers to the B<same data>. Sharing a hash
+will make its existing contents inaccessible, because afterwards it
+contains the same data that all other shared hashes contain. The result
+is that you get a hash with global semantics but with lexical scope
+(assuming C<%HASH> is a lexical variable).
+
+There are a few benefits of using C<share> over using a "regular"
+global hash. First, you don't have to decide what package the hash will
+belong to, which is annoying when you have specs in several packages
+referencing the same shared examples. You also don't have to clutter
+your examples with colons for fully-qualified names. For example, at my
+company our specs go in the "ICA::TestCase" hierarchy, and
+"$ICA::TestCase::Some::Package::variable" is exhausting to both the eyes
+and the hands. Lastly, using C<share> allows C<Test::Spec> to provide
+this functionality without deciding on the variable name for you (and
+thereby potentially clobbering one of your variables).
+
+  share %vars;      # %vars now refers to the global share
+  share my %vars;   # declare and share %vars in one step
+
 =item spec_helper FILESPEC
 
 Loads the Perl source in C<FILESPEC> into the current spec's package. If
@@ -766,6 +848,61 @@ Shared example groups may be included in other shared groups:
   ok 2 - Officer should be bonusable
   ok 3 - Officer should be payable
 
+=head3 Refactoring into files
+
+If you want to factor specs into separate files, variable scopes can be
+tricky. This is especially true if you follow the recommended pattern
+and give each spec its own package name. C<Test::Spec> offers a couple
+of functions that ease this process considerably: L<share|/share %HASH>
+and L<spec_helper|/spec_helper FILESPEC>.
+
+Consider the browsers example from C<shared_examples_for>. A real
+browser specification would be large, so putting the specs for all
+browsers in the same file would be a bad idea. So let's say we create
+C<all_browsers.pl> for the shared examples, and give Safari and Firefox
+C<safari.t> and C<firefox.t>, respectively. 
+
+The problem then becomes: how does the code in C<all_browsers.pl> access
+the C<$browser> variable? In L<the example code|/shared_examples_for DESCRIPTION =E<gt> CODE>, 
+C<$browser> is a lexical variable that is in scope for all the examples.
+But once those examples are split into multiple files, you would have to
+use either package global variables or worse, come up with some other
+hack. This is where C<share> and C<spec_helper> come in.
+
+  # safari.t
+  package Testcase::Safari;
+  use Test::Spec;
+  spec_helper 'all_browsers.pl';
+
+  describe "Safari" => sub {
+    share my %vars;
+    before all => sub { $vars{browser} = Safari->new };
+    it_should_behave_like "all browsers";
+    it "should have safari features";
+  };
+
+  # firefox.t
+  package Testcase::Firefox;
+  use Test::Spec;
+  spec_helper 'all_browsers.pl';
+
+  describe "Firefox" => sub {
+    share my %vars;
+    before all => sub { $vars{browser} = Firefox->new };
+    it_should_behave_like "all browsers";
+    it "should have firefox features";
+  };
+
+  # in all_browsers.pl
+  shared_examples_for "all browsers" => sub {
+    # doesn't have to be the same name!
+    share my %t;
+    it "should open a URL" => sub {
+      ok $t{browser}->open("http://www.google.com/");
+    };
+    ...
+  };
+
 =head2 Order of execution
 
 This example, shamelessly adapted from the RSpec website, gives an overview of
